@@ -34,27 +34,29 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import annotations
 
 from typing import Optional
 
 import numpy as np
 
+from phonopy.cui.load_helper import get_nac_params
 from phonopy.file_IO import parse_disp_yaml, write_FORCE_SETS
-from phonopy.interface.calculator import get_force_sets, get_force_sets_wien2k
+from phonopy.interface.calculator import get_calc_dataset, get_calc_dataset_wien2k
 from phonopy.interface.lammps import rotate_lammps_forces
 from phonopy.interface.phonopy_yaml import PhonopyYaml
 
 
 def create_FORCE_SETS(
-    interface_mode,
-    force_filenames,
+    interface_mode: str,
+    force_filenames: list[str],
     phpy_yaml: Optional[PhonopyYaml] = None,
-    symmetry_tolerance=None,
-    wien2k_P1_mode=False,
-    force_sets_zero_mode=False,
-    disp_filename="disp.yaml",
-    force_sets_filename="FORCE_SETS",
-    write_forcesets_yaml=False,
+    symmetry_tolerance: Optional[float] = None,
+    wien2k_P1_mode: bool = False,
+    force_sets_zero_mode: bool = False,
+    disp_filename: str = "disp.yaml",
+    force_sets_filename: str = "FORCE_SETS",
+    save_params: bool = False,
     log_level=0,
 ):
     """Create FORCE_SETS from phonopy_disp.yaml and calculator output files.
@@ -77,7 +79,7 @@ def create_FORCE_SETS(
                 '  "disp.yaml" is still supported for reading except for '
                 "Wien2k interface, "
             )
-            print("  but is deprecated.")
+            print("  and this supported will be removed at version 3.")
             print("")
         if force_sets_zero_mode:
             print(
@@ -118,7 +120,7 @@ def create_FORCE_SETS(
     ):
         force_sets = []
     elif interface_mode == "wien2k":
-        force_sets = get_force_sets_wien2k(
+        calc_dataset = get_calc_dataset_wien2k(
             force_filenames,
             supercell,
             disp_dataset,
@@ -126,13 +128,16 @@ def create_FORCE_SETS(
             symmetry_tolerance=symmetry_tolerance,
             verbose=(log_level > 0),
         )
+        force_sets = calc_dataset["forces"]
     else:
-        force_sets = get_force_sets(
+        calc_dataset = get_calc_dataset(
             interface_mode,
             num_atoms,
             force_filenames,
             verbose=(log_level > 0),
         )
+        force_sets = calc_dataset["forces"]
+
     if interface_mode == "lammps":
         rotate_lammps_forces(force_sets, supercell.cell, verbose=(log_level > 0))
 
@@ -145,19 +150,30 @@ def create_FORCE_SETS(
         elif dataset_type == 2:
             disp_dataset["forces"] = np.array(force_sets, dtype="double", order="C")
         else:
-            raise RuntimeError("FORCE_SETS could not be created.")
+            raise RuntimeError("Force sets could not be found.")
 
-        write_FORCE_SETS(disp_dataset, filename=force_sets_filename)
+        if "supercell_energies" in calc_dataset:
+            energies = np.array(calc_dataset["supercell_energies"], dtype="double")
+            if dataset_type == 1:
+                for energy, disp in zip(energies, disp_dataset["first_atoms"]):
+                    disp["supercell_energy"] = energy
+            elif dataset_type == 2:
+                disp_dataset["supercell_energies"] = energies
 
-        if log_level > 0:
-            print('"%s" has been created.' % force_sets_filename)
-
-        if disp_filename != "disp.yaml" and write_forcesets_yaml:
+        if save_params:
             phpy_yaml.dataset = disp_dataset
-            with open("phonopy_force_sets.yaml", "w") as w:
+            nac_params = get_nac_params(primitive=phpy_yaml.primitive)
+            if nac_params:
+                phpy_yaml.nac_params = nac_params
+            yaml_filename = "phonopy_params.yaml"
+            with open(yaml_filename, "w") as w:
                 w.write(str(phpy_yaml))
             if log_level > 0:
-                print('"%s" has been created.' % "phonopy_force_sets.yaml")
+                print(f'"{yaml_filename}" has been created.')
+        else:
+            write_FORCE_SETS(disp_dataset, filename=force_sets_filename)
+            if log_level > 0:
+                print(f'"{force_sets_filename}" has been created.')
 
     else:
         if log_level > 0:
