@@ -33,10 +33,12 @@
 # LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
+from __future__ import annotations
 
 import warnings
+from collections.abc import Sequence
 from math import gcd
-from typing import Optional
+from typing import Optional, Union
 
 import numpy as np
 
@@ -60,20 +62,45 @@ class PhonopyAtoms:
 
     Originally this aimed to be compatible ASE Atoms class, but now not.
 
+    Attributes
+    ----------
+    cell : np.ndarray
+        Basis vectors (a, b, c) given in row vectors.
+    positions : np.ndarray
+        Positions of atoms in Cartesian coordinates.
+        shape=(natom, 3), dtype='double', order='C'
+    scaled_positions : np.ndarray
+        Positions of atoms in fractional (crystallographic) coordinates.
+        shape=(natom, 3), dtype='double', order='C'
+    symbols : list[str]
+        List of chemical symbols of atoms.
+    numbers : np.ndarray
+        Atomic numbers.
+        shape=(natom,), dtype='intc'
+    masses : np.ndarray, optional
+        Atomic masses.
+        shape=(natom,), dtype='double'
+    magnetic_moments : np.ndarray, optional
+        shape=(natom,) or (natom, 3), dtype='double', order='C'
+    volume : float
+        Cell volume.
+    Z : int
+        Number of formula units in this cell.
+
     """
 
     def __init__(
         self,
-        symbols=None,
-        numbers=None,
-        masses=None,
-        magnetic_moments=None,
-        scaled_positions=None,
-        positions=None,
-        cell=None,
+        symbols: Optional[Sequence] = None,
+        numbers: Optional[Union[Sequence, np.ndarray]] = None,
+        masses: Optional[Union[Sequence, np.ndarray]] = None,
+        magnetic_moments: Optional[Union[Sequence, np.ndarray]] = None,
+        scaled_positions: Optional[Union[Sequence, np.ndarray]] = None,
+        positions: Optional[Union[Sequence, np.ndarray]] = None,
+        cell: Optional[Union[Sequence, np.ndarray]] = None,
         atoms: Optional["PhonopyAtoms"] = None,
-        magmoms=None,
-        pbc=True,
+        magmoms: Optional[Union[Sequence, np.ndarray]] = None,
+        pbc: Optional[bool] = None,
     ):  # pbc is dummy argument, and never used.
         """Init method."""
         if magmoms is not None:
@@ -82,6 +109,12 @@ class PhonopyAtoms:
                 "Use magnetic_moments instead.",
                 DeprecationWarning,
             )
+        if pbc is not None:
+            warnings.warn(
+                "PhonopyAtoms.__init__ parameter of pbc is deprecated. "
+                "It is considered always True.",
+                DeprecationWarning,
+            )
         if atoms:
             self._set_parameters(
                 numbers=atoms.numbers,
@@ -89,7 +122,6 @@ class PhonopyAtoms:
                 magnetic_moments=atoms.magnetic_moments,
                 scaled_positions=atoms.scaled_positions,
                 cell=atoms.cell,
-                pbc=True,
             )
         else:
             self._set_parameters(
@@ -100,20 +132,17 @@ class PhonopyAtoms:
                 scaled_positions=scaled_positions,
                 positions=positions,
                 cell=cell,
-                pbc=True,
             )
 
     def _set_parameters(
         self,
-        symbols=None,
-        numbers=None,
-        masses=None,
-        magnetic_moments=None,
-        scaled_positions=None,
-        positions=None,
-        cell=None,
-        atoms: Optional["PhonopyAtoms"] = None,
-        pbc=True,
+        symbols: Optional[Sequence] = None,
+        numbers: Optional[Union[Sequence, np.ndarray]] = None,
+        masses: Optional[Union[Sequence, np.ndarray]] = None,
+        magnetic_moments: Optional[Union[Sequence, np.ndarray]] = None,
+        scaled_positions: Optional[Union[Sequence, np.ndarray]] = None,
+        positions: Optional[Union[Sequence, np.ndarray]] = None,
+        cell: Optional[Union[Sequence, np.ndarray]] = None,
     ):
         self._cell = None
         self._scaled_positions = None
@@ -128,7 +157,7 @@ class PhonopyAtoms:
         self._set_masses(masses)
 
         # (initial) magnetic moments
-        self._magmoms = None
+        self._magnetic_moments = None
         self._set_magnetic_moments(magnetic_moments)
 
         # numbers and symbols
@@ -142,6 +171,7 @@ class PhonopyAtoms:
             self._symbols_to_masses()
 
         self._check()
+        self._finalize()
 
     def __len__(self):
         """Return number of atoms."""
@@ -320,16 +350,25 @@ class PhonopyAtoms:
 
     @property
     def magnetic_moments(self):
-        """Setter and getter of magnetic moments. For getter, copy is returned."""
-        if self._magmoms is None:
+        """Setter and getter of magnetic moments. For getter, copy is returned.
+
+        shape=(natom,) or (natom, 3), dtype='double', order='C'
+
+        For setter, the formar can be specified by (natom, 1), which will be
+        recognized as (natom,) and the latter can be specified by (natom * 3,),
+        which will be converted to (natom, 3).
+
+        """
+        if self._magnetic_moments is None:
             return None
         else:
-            return self._magmoms.copy()
+            return self._magnetic_moments.copy()
 
     @magnetic_moments.setter
-    def magnetic_moments(self, magmoms):
-        self._set_magnetic_moments(magmoms)
+    def magnetic_moments(self, magnetic_moments):
+        self._set_magnetic_moments(magnetic_moments)
         self._check()
+        self._finalize()
 
     def get_magnetic_moments(self):
         """Return magnetic moments."""
@@ -404,9 +443,9 @@ class PhonopyAtoms:
 
     def _set_magnetic_moments(self, magmoms):
         if magmoms is None:
-            self._magmoms = None
+            self._magnetic_moments = None
         else:
-            self._magmoms = np.array(magmoms, dtype="double")
+            self._magnetic_moments = np.array(np.ravel(magmoms), dtype="double")
 
     def _set_cell_and_positions(self, cell, positions=None, scaled_positions=None):
         self._set_cell(cell)
@@ -429,6 +468,12 @@ class PhonopyAtoms:
             self._masses = np.array(masses, dtype="double")
 
     def _check(self):
+        """Check number of eleemnts in arrays.
+
+        Do not modify the arrays. Modification of array shapes should be done in
+        ``self._finalize()``.
+
+        """
         if self._cell is None:
             raise RuntimeError("cell is not set.")
         if self._scaled_positions is None:
@@ -442,9 +487,18 @@ class PhonopyAtoms:
         if self._masses is not None:
             if len(self._numbers) != len(self._masses):
                 raise RuntimeError("len(numbers) != len(masses).")
-        if self._magmoms is not None:
-            if len(self._numbers) != len(self._magmoms):
-                raise RuntimeError("len(numbers) != len(magmoms).")
+        if self._magnetic_moments is not None:
+            if len(self._magnetic_moments.ravel()) not in (len(self), len(self) * 3):
+                raise RuntimeError(
+                    "magnetic_moments has to have shape=(natom,) or (natom, 3)."
+                )
+
+    def _finalize(self):
+        """Modify array shapes to those expeted to be exposed."""
+        # When non collinear magnetic moments is given in a flat array.
+        if self.magnetic_moments is not None:
+            if len(self.magnetic_moments.ravel()) == len(self) * 3:
+                self._magnetic_moments = np.reshape(self._magnetic_moments, (-1, 3))
 
     def copy(self):
         """Return copy of itself."""
@@ -452,7 +506,7 @@ class PhonopyAtoms:
             cell=self._cell,
             scaled_positions=self._scaled_positions,
             masses=self._masses,
-            magnetic_moments=self._magmoms,
+            magnetic_moments=self._magnetic_moments,
             symbols=self._symbols,
         )
 
@@ -462,10 +516,15 @@ class PhonopyAtoms:
         If magmams is set, (cell, scaled_position, numbers, magmoms) is returned.
 
         """
-        if self._magmoms is None:
+        if self._magnetic_moments is None:
             return (self._cell, self._scaled_positions, self._numbers)
         else:
-            return (self._cell, self._scaled_positions, self._numbers, self._magmoms)
+            return (
+                self._cell,
+                self._scaled_positions,
+                self._numbers,
+                self._magnetic_moments,
+            )
 
     def to_tuple(self):
         """Return (cell, scaled_position, numbers).
@@ -489,10 +548,10 @@ class PhonopyAtoms:
             masses = [None] * len(self._symbols)
         else:
             masses = self._masses
-        if self._magmoms is None:
+        if self._magnetic_moments is None:
             magmoms = [None] * len(self._symbols)
         else:
-            magmoms = self._magmoms
+            magmoms = self._magnetic_moments
         for i, (s, v, m, mag) in enumerate(
             zip(self._symbols, self._scaled_positions, masses, magmoms)
         ):
@@ -501,7 +560,11 @@ class PhonopyAtoms:
             if m is not None:
                 lines.append("  mass: %f" % m)
             if mag is not None:
-                lines.append("  magnetic_moment: %.8f" % mag)
+                if mag.ndim == 0:
+                    mag_str = f"{mag:.8f}"
+                else:
+                    mag_str = f"[{mag[0]:.8f}, {mag[1]:.8f}, {mag[2]:.8f}]"
+                lines.append(f"  magnetic_moment: {mag_str}")
         return lines
 
     def __str__(self):
